/**
 * CardAreaGUI.java
 * Group 7, Object Oriented Software Engineering
 * October 20, 2009
 */
package edu.jhu.cs.oose.elevel;

import com.trolltech.qt.core.QSize;
import com.trolltech.qt.core.Qt;
import com.trolltech.qt.gui.QGridLayout;
import com.trolltech.qt.gui.QMainWindow;
import com.trolltech.qt.gui.QPushButton;
import com.trolltech.qt.gui.QTextEdit;
import com.trolltech.qt.gui.QWidget;

/**
 * Uses the basic interface class QWidget to design
 * the <code>Card</code> GUI
 */
public class CardAreaGUI extends QWidget
{
	/** The QLayout of the card area */
	QGridLayout gridLayout;

	/** The minimum size of the card area */
	final static int minWidth = 350;
	final static int minHeight = 200;

	/**
	 * Initializes the basic layout of a <code>Card</code>, including previous and next card buttons
	 * 
	 * @param currentCard
	 *        the current <code>Card</code>
	 * @param window
	 *        the <code>MainWindow</code> of E-Level
	 */
	public CardAreaGUI(Card currentCard, QMainWindow window)
	{
		this.gridLayout = new QGridLayout(this);
		setLayout(this.gridLayout);

		displayEmptyCard();

		QPushButton previousButton = new QPushButton(tr("Previous"), this);
		previousButton.clicked.connect(window, "previousCard()");
		this.gridLayout.addWidget(previousButton, 1, 0, Qt.AlignmentFlag.AlignLeft);

		QPushButton nextButton = new QPushButton(tr("Next"), this);
		nextButton.clicked.connect(window, "nextCard()");
		this.gridLayout.addWidget(nextButton, 1, 2, Qt.AlignmentFlag.AlignRight);
	}

	/**
	 * Displays the current card
	 * 
	 * @param currentCard
	 *        the <code>Card</code> to be displayed in the card area
	 */
	private void displayCard(Card currentCard)
	{
		if(currentCard != null)
		{
			QTextEdit question = new QTextEdit(currentCard.getQuestion());
			question.setReadOnly(true);
			question.setMinimumSize(new QSize(minWidth, minHeight));
			this.gridLayout.addWidget(question, 0, 0);

			QTextEdit answer = new QTextEdit(currentCard.getAnswer());
			answer.setReadOnly(true);
			answer.setMinimumSize(new QSize(minWidth, minHeight));
			this.gridLayout.addWidget(answer, 2, 0);

			QTextEdit additionalInfo = new QTextEdit(currentCard.getAdditionalInfo());
			additionalInfo.setReadOnly(true);
			additionalInfo.setMinimumSize(new QSize(minWidth, minHeight));
			this.gridLayout.addWidget(additionalInfo, 0, 2);

			QTextEdit hint = new QTextEdit(currentCard.getHint());
			hint.setReadOnly(true);
			hint.setMinimumSize(new QSize(minWidth, minHeight));
			this.gridLayout.addWidget(hint, 2, 2);
		}
	}

	/**
	 * Displays an empty <code>Card</code> in the card area
	 */
	public void displayEmptyCard()
	{
		displayCard(new Card());
	}
}
