/**
 * CoreTest.java
 * Group 7, Object Oriented Software Engineering
 */
package edu.jhu.cs.oose.elevel;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Class containing our primary test suite. New tests should be added in the form of methods to this class
 * 
 * @author Greg Anderson
 */
public class CoreTest extends TestCase
{
	private Deck testDeck;

	public CoreTest(String name)
	{
		super(name);
	}

	/**
	 * Forms the testing suite
	 * 
	 * @return Test the test suite
	 */
	public static Test suite()
	{
		TestSuite test = new TestSuite();
		test.addTest(new CoreTest("testAddCard"));
		test.addTest(new CoreTest("testDeckShuffle"));
		return test;
	}

	/**
	 * Initializes common objects
	 */
	protected void setUp() throws Exception
	{
		super.setUp();
		testDeck = new Deck("test deck");
	}

	/**
	 * Cleanups the common objects
	 */
	protected void tearDown() throws Exception
	{
		super.tearDown();
		testDeck = null;
	}

	/**
	 * Tests the ability to shuffle {@link Card}s in a {@link Deck}
	 */
	public void testDeckShuffle()
	{
		for(int i = 0; i < 100; i++)
			testDeck.shuffle();
		assert (100 == testDeck.numCards());

		testDeck.clearCards();
		testDeck.shuffle();
		assert (0 == testDeck.numCards());
	}

	/**
	 * Tests the ability to add <code>Card</code>s
	 */
	public void testAddCard()
	{
		for(int i = 0; i < 100; i++)
			testDeck.addCard(new Card("test question", "", "", ""));
		assert (100 == testDeck.numCards());
	}
}
