/**
 * DeckDialog.java
 * Group 7, Object Oriented Software Engineering
 * Oct 25, 2009
 */
package edu.jhu.cs.oose.elevel;

import com.trolltech.qt.QSignalEmitter;
import com.trolltech.qt.core.Qt;
import com.trolltech.qt.gui.QCloseEvent;
import com.trolltech.qt.gui.QDialog;
import com.trolltech.qt.gui.QDialogButtonBox;
import com.trolltech.qt.gui.QFileDialog;
import com.trolltech.qt.gui.QGridLayout;
import com.trolltech.qt.gui.QHBoxLayout;
import com.trolltech.qt.gui.QLabel;
import com.trolltech.qt.gui.QLayout;
import com.trolltech.qt.gui.QLineEdit;
import com.trolltech.qt.gui.QPushButton;
import com.trolltech.qt.gui.QVBoxLayout;
import com.trolltech.qt.gui.QWidget;

/**
 * Implements a dialog for creating a new <code>Deck</code>
 * 
 * @author Jesse Yates
 */
public class DeckDialog extends QDialog
{
	private QLabel name;
	private QLineEdit nameEdit;
	// private QCheckBox caseCheckBox;
	// private QCheckBox fromStartCheckBox;
	// private QCheckBox wholeWordsCheckBox;
	// private QCheckBox searchSelectionCheckBox;
	// private QCheckBox backwardCheckBox;
	private QDialogButtonBox buttonBox;
	private QPushButton okButton;
	private QPushButton detailsButton;
	private QWidget extension;
	private QPushButton export;
	private String exportDir;

	public final QSignalEmitter.Signal1<Deck> closing = new QSignalEmitter.Signal1<Deck>();

	/**
	 * Creates all buttons necessary for the <code>Deck</code> and connects them to the appropriate signal
	 * 
	 * @param parent
	 *        A <code>QWidget</code> representing the parent <code>QWidget</code>
	 */
	public DeckDialog(QWidget parent)
	{
		this.extension = new QWidget();
		this.exportDir = (String) Preferences.getInstance().getValue("DEFAULT_EXPORT_LOCATION");

		this.name = new QLabel(tr("Name:"));
		this.nameEdit = new QLineEdit();
		this.name.setBuddy(this.nameEdit);

		/*
		 * caseCheckBox = new QCheckBox(tr("Match &case"));
		 * fromStartCheckBox = new QCheckBox(tr("Search from &start"));
		 * fromStartCheckBox.setChecked(true);
		 */

		this.okButton = new QPushButton(tr("&OK"));
		this.okButton.setDefault(true);
		this.okButton.clicked.connect(this, "close()");

		this.detailsButton = new QPushButton(tr("&Options>>"));
		this.detailsButton.setCheckable(true);
		this.detailsButton.setAutoDefault(false);
		this.detailsButton.toggled.connect(this.extension, "setVisible(boolean)");

		this.buttonBox = new QDialogButtonBox(Qt.Orientation.Vertical);
		this.buttonBox.addButton(this.okButton, QDialogButtonBox.ButtonRole.ActionRole);
		this.buttonBox.addButton(this.detailsButton, QDialogButtonBox.ButtonRole.ActionRole);

		this.export = new QPushButton(tr("Export Location"), this);
		this.export.clicked.connect(this, "changeExportLocation()");

		/*
		 * wholeWordsCheckBox = new QCheckBox(tr("&Whole words"));
		 * backwardCheckBox = new QCheckBox(tr("Search &backward"));
		 * searchSelectionCheckBox = new QCheckBox(tr("Search se&lection"));
		 */

		QGridLayout extensionLayout = new QGridLayout();
		extensionLayout.setMargin(0);
		extensionLayout.addWidget(this.export, 0, 0, 1, 1);
		extensionLayout.addWidget(new QWidget(), 0, 1);
		extensionLayout.setColumnMinimumWidth(0, this.export.size().width());

		this.extension.setLayout(extensionLayout);

		QHBoxLayout topLeftLayout = new QHBoxLayout();
		topLeftLayout.addWidget(this.name);
		topLeftLayout.addWidget(this.nameEdit);

		QVBoxLayout leftLayout = new QVBoxLayout();
		leftLayout.addLayout(topLeftLayout);
		// leftLayout.addWidget(caseCheckBox);
		// leftLayout.addWidget(fromStartCheckBox);
		leftLayout.addStretch(1);

		QGridLayout mainLayout = new QGridLayout();
		mainLayout.setSizeConstraint(QLayout.SizeConstraint.SetFixedSize);
		mainLayout.addLayout(leftLayout, 0, 0);
		mainLayout.addWidget(this.buttonBox, 0, 1);
		mainLayout.addWidget(this.extension, 1, 0, 1, 2);
		setLayout(mainLayout);

		setWindowTitle(tr("Extension"));
		this.extension.hide();
	}

	/**
	 * Sets the export location for this new deck to the location specified by the user in a dialog
	 */
	@SuppressWarnings("unused")
	private void changeExportLocation()
	{
		String initialPath = (String) Preferences.getInstance().getValue("DEFAULT_EXPORT_LOCATION");
		this.exportDir = QFileDialog.getExistingDirectory(this, this.tr("Deck Export Directory"), initialPath);
		if(!(this.exportDir == null || this.exportDir.equals("")))
		{
			// Assign a new path
			if(!this.exportDir.endsWith("/"))
				this.exportDir = this.exportDir + "/";
		}
		else
			this.exportDir = initialPath;
	}

	/**
	 * If the window attempts to close, determine if the <code>Card</code> should be saved
	 * 
	 * @see com.trolltech.qt.gui.QWidget#closeEvent(com.trolltech.qt.gui.QCloseEvent)
	 */
	public void closeEvent(QCloseEvent event)
	{
		System.out.println("Catching close event");
		Deck deck = new Deck(this.nameEdit.text());
		deck.setDiskLocation(this.exportDir + deck.getName() + ".elvl");
		deck.writeToDisk(this, deck.getDiskLocation());
		this.closing.emit(deck);
		event.accept();
	}
}
