/**
 * DeckTreeGUI.java
 * Group 7, Object Oriented Software Engineering
 * Oct 25, 2009
 */
package edu.jhu.cs.oose.elevel;

import com.trolltech.qt.core.QModelIndex;
import com.trolltech.qt.gui.QTreeView;

/**
 * It's actually a deck tree view, but it manages its model
 * so that the main window doesn't have to
 * 
 * @author Pablo Lee
 */
public class DeckTreeGUI extends QTreeView
{
	/** The tree model it works with to display the tree */
	DeckTreeModel treeModel;

	/** A signal it sends to the MainWindow to let it know the tree changed */
	public Signal1<Card> selectedCardChanged;

	/**
	 * Initializes the class by enabling the user to click or drag and drop objects
	 * in the tree gui such as {@link Deck}s and {@link Card}s
	 */
	public DeckTreeGUI(DeckTreeModel treeModel)
	{
		this.treeModel = treeModel;

		setHeaderHidden(true);

		setSelectionMode(SelectionMode.SingleSelection);
		setDragDropMode(DragDropMode.DragDrop);
		setDragEnabled(true);
		setAcceptDrops(true);
		setDropIndicatorShown(true);

		this.selectedCardChanged = new Signal1<Card>();
	}

	/**
	 * Called whenever a new selection's been made in the model,
	 * whether through the GUI or through the model itself.
	 * a <code>deck</code> or a new <code>card</code> and updates all signals to make that object the current object
	 */
	protected void currentChanged(QModelIndex current, QModelIndex previous)
	{
		// If something's been selected
		if(current != null || previous != null)
		{
			Object item = this.treeModel.indexToValue(current);

			// If the selected item's a deck
			if(this.treeModel.isDeck(item))
			{
				// Change the current deck, card
				Deck deck = (Deck) item;
				if(deck.getCards().size() > 0)
					deck.setCurrentCard(deck.getCard(0));
				this.treeModel.setCurrentDeck(deck);
			}
			// If it's a card
			else
			{
				// Set the new current deck and card
				Deck currentDeck = (Deck) this.treeModel.indexToValue(this.treeModel.parent(current));
				currentDeck.setCurrentCard((Card) item);

				this.treeModel.setCurrentDeck(currentDeck);
			}
		}
		// If nothing's been manually selected, and you're just updating the tree view
		// so that it matches the model
		else
			setCurrentIndex(this.treeModel.valueToIndex(this.treeModel.getCurrentDeck().getCurrentCard()));

		if(this.treeModel.getCurrentDeck().getCards().size() > 0)
		{
			Card newCurrentCard = this.treeModel.getCurrentDeck().getCurrentCard();
			this.selectedCardChanged.emit(newCurrentCard);
		}
	}

	/**
	 * Signals that something changed in the tree model
	 */
	protected void dataChanged(QModelIndex topLeft, QModelIndex bottomRight)
	{
		Card currentCard = this.treeModel.getCurrentDeck().getCurrentCard();
		this.selectedCardChanged.emit(currentCard);
	}
}
