/**
 * EditCardWindow.java
 * Group 7, Object Oriented Software Engineering
 * October 10, 2009
 */
package edu.jhu.cs.oose.elevel;

import java.util.HashMap;

/**
 * The underlying model class that handles editing any features of a <code>card</code>
 * 
 * @author Jesse Yates
 */
public class EditCardWindow
{
	/** The <code>Card</code> currently being edited */
	private Card card;

	/** The <code>ToolBar</code> currently being used */
	private ToolBar editToolbar;

	/** The <code>Deck</code> currently selected */
	private Deck currentDeck;

	/**
	 * Constructor for the editCard model, creates the default {@link ToolBar} to be used
	 * 
	 * @param currentDeck
	 *        the {@link Deck} currently selected
	 */
	public EditCardWindow(Deck currentDeck)
	{
		this.card = currentDeck.getCurrentCard();
		this.currentDeck = currentDeck;
		if(card == null)
		{
			this.card = new Card();
		}

		this.editToolbar = new DefaultToolBar();
	}

	/**
	 * Constructor for the editCard model
	 * 
	 * @param currentDeck
	 *        The <code>Card</code> to be edited
	 * @param currentToolbar
	 *        The <code>ToolBar</code> to edit with
	 */
	public EditCardWindow(Deck currentDeck, ToolBar currentToolbar)
	{
		this(currentDeck);
		// TODO change this line to a different toolbar
	}

	/**
	 * Returns the <code>Card</code> currently being edited
	 * 
	 * @return a {@link Card} representing the card currently being edited
	 */
	public Card getCard()
	{
		return card;
	}

	/**
	 * Set the <code>Card</code> being currently edited to the specified {@link Card}
	 * 
	 * @param c
	 *        a <code>Card</code> representing the card currently being edited
	 */
	public void setCard(Card c)
	{
		this.card = c;
	}

	/**
	 * Return the {@link ToolBar} currently associated with this <code>EditCardWindow</code>
	 * 
	 * @return the {@link ToolBar} currently associated with this <code>EditCardWindow</code>
	 */
	public ToolBar getToolbar()
	{
		return editToolbar;
	}

	/**
	 * Set the {@link ToolBar} currently being used to the specified {@link ToolBar}
	 * 
	 * @param e
	 *        the {@link ToolBar} to associate with this <code>EditCardWindow</code>
	 */
	public void setToolbar(ToolBar e)
	{
		this.editToolbar = e;
	}

	/**
	 * Saves a new card to the deck with the properties passed in
	 * 
	 * @param question
	 *        the question on the flash card
	 * @param answer
	 *        the answer to the question on the flash card
	 * @param hint
	 *        the user specified hint to the answer
	 * @param addinfo
	 *        any additional information given
	 * @param pref
	 *        prefences
	 */
	public void save(String question, String answer, String hint, String addinfo, HashMap<String, Boolean> pref)
	{
		this.card.setValues(question, answer, hint, addinfo, pref);
		this.currentDeck.addCard(this.card);
	}
}
