/**
 * TestWindow.java
 * Group 7, Object Oriented Software Engineering
 * October 10, 2009
 */
package edu.jhu.cs.oose.elevel;

/**
 * The underlying data model to be displayed in the associated {@link TestWindowGUI}
 * 
 * @author Jesse Yates
 */
public class TestWindow
{
	/** The <code>Deck</code> currently being tested */
	private Deck deck;

	/** The statistics for the current test */
	private DeckStat testStat;

	/** The number of cards in the deck */
	private int numCards;

	/** The number of cards tested */
	private int cardsTested;

	/**
	 * Initializes a new <code>TestWindow</code> with the specified <code>Deck</code>
	 * 
	 * @param currentDeck
	 *        a <code>Deck</code> representing the currently selected <code>Deck</code> on which to test
	 */
	public TestWindow(Deck currentDeck)
	{
		this.deck = currentDeck;
		this.numCards = this.deck.numCards();
		createTest();
	}

	/**
	 * Sets the currently selected <code>Deck</code> to the specified {@link Deck}
	 * 
	 * @param d
	 *        a <code>Deck</code> to assign to the currently selected deck
	 */
	public void setDeck(Deck d)
	{
		this.deck = d;
	}

	/**
	 * Check the given answer with the answer stored in the <code>Deck</code>
	 * 
	 * @param s
	 *        the <code>String</code> to check
	 */
	public void checkAnswer(String s)
	{
		checkAnswer(this.deck.getCurrentCard().checkAnswer(s));
	}

	/**
	 * Determine if the answer given to the previous {@link Card} was correct.
	 * Used for <code>Card</code>s with no computer-checkable answer.
	 * 
	 * @param answer
	 *        <code>true</code> if the previous answer was correct, <code>false</code> otherwise.
	 */
	private void checkAnswer(boolean answer)
	{
		testStat.incrementPercent(answer);
	}

	/**
	 * Increment the number of correct answers
	 */
	public void rightAnswer()
	{
		testStat.incrementPercent(true);
	}

	/**
	 * Increment the number of incorrect answers
	 */
	public void wrongAnswer()
	{
		testStat.incrementPercent(false);
	}

	/**
	 * Completes the test and permanently associates the current statistics with the current <code>Deck</code>
	 */
	public void finishTest()
	{
		deck.addDeckStat(testStat);
		this.deck.selectNextCard();
		// Other closing things
	}

	/**
	 * Executes a test with the currently <code>Deck</code>
	 */
	public void newTest()
	{
		finishTest();
		createTest();
	}

	/**
	 * Initializes default parameters for a new test
	 */
	private void createTest()
	{
		this.cardsTested = 0;
		this.testStat = new DeckStat(System.currentTimeMillis());
	}

	/**
	 * Selects the next <code>Card</code>
	 * 
	 * @return <code>true</code> if there is a next <code>Card</code>, <code>false</code> if the test is over
	 */
	public boolean nextCard()
	{
		cardsTested++;
		if(cardsTested >= numCards)
			return false;
		this.deck.selectNextCard();
		return true;
	}

	/**
	 * Get the current <code>Card</code> from the {@link Deck}
	 * 
	 * @return the current <code>Card</code>
	 */
	public Card currentCard()
	{
		return this.deck.getCurrentCard();
	}
}
